binary_contains_marker

Function binary_contains_marker 

pub fn binary_contains_marker(path: &Path, marker: &str) -> Result<bool>
Check if a binary contains a specific marker string.

This is used to verify that the remote worker actually compiled the code by checking for a unique test marker that was added to the source.

Arguments

  • path - Path to the binary file
  • marker - The marker string to search for

Returns

true if the marker is found in the binary’s string data