pub struct DependencyPlanIssue {
pub code: String,
pub message: String,
pub risk: DependencyRiskClass,
pub diagnostics: Vec<String>,
}Expand description
Planner issue emitted for unsafe or unverifiable closure states.
Fields
code: Stringmessage: Stringrisk: DependencyRiskClassdiagnostics: Vec<String>Trait Implementations
Sourceimpl Clone for DependencyPlanIssue
impl Clone for DependencyPlanIssue
Sourcefn clone(&self) -> DependencyPlanIssue
fn clone(&self) -> DependencyPlanIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DependencyPlanIssue
impl Debug for DependencyPlanIssue
Sourceimpl<'de> Deserialize<'de> for DependencyPlanIssue
impl<'de> Deserialize<'de> for DependencyPlanIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DependencyPlanIssue
impl PartialEq for DependencyPlanIssue
Sourcefn eq(&self, other: &DependencyPlanIssue) -> bool
fn eq(&self, other: &DependencyPlanIssue) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DependencyPlanIssue
impl Serialize for DependencyPlanIssue
impl Eq for DependencyPlanIssue
impl StructuralPartialEq for DependencyPlanIssue