pub struct ProcessTriageActionRequest {
pub action_class: ProcessTriageActionClass,
pub pid: u32,
pub reason_code: String,
pub signal: Option<String>,
}Expand description
Action request item proposed by detector/planner.
Fields
action_class: ProcessTriageActionClasspid: u32reason_code: Stringsignal: Option<String>Trait Implementations
Sourceimpl Clone for ProcessTriageActionRequest
impl Clone for ProcessTriageActionRequest
Sourcefn clone(&self) -> ProcessTriageActionRequest
fn clone(&self) -> ProcessTriageActionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessTriageActionRequest
impl Debug for ProcessTriageActionRequest
Sourceimpl<'de> Deserialize<'de> for ProcessTriageActionRequest
impl<'de> Deserialize<'de> for ProcessTriageActionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProcessTriageActionRequest
impl JsonSchema for ProcessTriageActionRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProcessTriageActionRequest
impl PartialEq for ProcessTriageActionRequest
Sourcefn eq(&self, other: &ProcessTriageActionRequest) -> bool
fn eq(&self, other: &ProcessTriageActionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ProcessTriageActionRequest
impl StructuralPartialEq for ProcessTriageActionRequest