pub struct ProcessTriageCommandBudget {
pub command: ProcessTriageAdapterCommand,
pub timeout_secs: u64,
pub retries: u32,
}Expand description
Adapter command budget used in timeout/retry policy.
Fields
command: ProcessTriageAdapterCommandtimeout_secs: u64retries: u32Trait Implementations
Sourceimpl Clone for ProcessTriageCommandBudget
impl Clone for ProcessTriageCommandBudget
Sourcefn clone(&self) -> ProcessTriageCommandBudget
fn clone(&self) -> ProcessTriageCommandBudget
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessTriageCommandBudget
impl Debug for ProcessTriageCommandBudget
Sourceimpl<'de> Deserialize<'de> for ProcessTriageCommandBudget
impl<'de> Deserialize<'de> for ProcessTriageCommandBudget
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProcessTriageCommandBudget
impl JsonSchema for ProcessTriageCommandBudget
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProcessTriageCommandBudget
impl PartialEq for ProcessTriageCommandBudget
Sourcefn eq(&self, other: &ProcessTriageCommandBudget) -> bool
fn eq(&self, other: &ProcessTriageCommandBudget) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ProcessTriageCommandBudget
impl StructuralPartialEq for ProcessTriageCommandBudget