pub struct ProcessTriageFailure {
pub kind: ProcessTriageFailureKind,
pub code: String,
pub message: String,
pub remediation: Vec<String>,
}Expand description
Failure payload.
Fields
kind: ProcessTriageFailureKindcode: Stringmessage: Stringremediation: Vec<String>Trait Implementations
Sourceimpl Clone for ProcessTriageFailure
impl Clone for ProcessTriageFailure
Sourcefn clone(&self) -> ProcessTriageFailure
fn clone(&self) -> ProcessTriageFailure
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessTriageFailure
impl Debug for ProcessTriageFailure
Sourceimpl<'de> Deserialize<'de> for ProcessTriageFailure
impl<'de> Deserialize<'de> for ProcessTriageFailure
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProcessTriageFailure
impl JsonSchema for ProcessTriageFailure
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProcessTriageFailure
impl PartialEq for ProcessTriageFailure
Sourcefn eq(&self, other: &ProcessTriageFailure) -> bool
fn eq(&self, other: &ProcessTriageFailure) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProcessTriageFailure
impl Serialize for ProcessTriageFailure
impl Eq for ProcessTriageFailure
impl StructuralPartialEq for ProcessTriageFailure