pub struct ProcessTriageResponse {
pub schema_version: String,
pub correlation_id: String,
pub status: ProcessTriageResponseStatus,
pub escalation_level: ProcessTriageEscalationLevel,
pub executed_actions: Vec<ProcessTriageActionResult>,
pub failure: Option<ProcessTriageFailure>,
pub audit: ProcessTriageAuditRecord,
}Expand description
Adapter response schema.
Fields
schema_version: Stringcorrelation_id: Stringstatus: ProcessTriageResponseStatusescalation_level: ProcessTriageEscalationLevelexecuted_actions: Vec<ProcessTriageActionResult>failure: Option<ProcessTriageFailure>audit: ProcessTriageAuditRecordTrait Implementations
Sourceimpl Clone for ProcessTriageResponse
impl Clone for ProcessTriageResponse
Sourcefn clone(&self) -> ProcessTriageResponse
fn clone(&self) -> ProcessTriageResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessTriageResponse
impl Debug for ProcessTriageResponse
Sourceimpl<'de> Deserialize<'de> for ProcessTriageResponse
impl<'de> Deserialize<'de> for ProcessTriageResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProcessTriageResponse
impl JsonSchema for ProcessTriageResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProcessTriageResponse
impl PartialEq for ProcessTriageResponse
Sourcefn eq(&self, other: &ProcessTriageResponse) -> bool
fn eq(&self, other: &ProcessTriageResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProcessTriageResponse
impl Serialize for ProcessTriageResponse
impl Eq for ProcessTriageResponse
impl StructuralPartialEq for ProcessTriageResponse