pub fn classify_command_detailed(cmd: &str) -> ClassificationDetailsExpand description
Classify a shell command with detailed tier decisions for diagnostics.
pub fn classify_command_detailed(cmd: &str) -> ClassificationDetailsClassify a shell command with detailed tier decisions for diagnostics.