pub struct AllowWithModifiedCommandOutput {
pub hook_specific_output: AllowWithModifiedHookSpecificOutput,
}Expand description
Output to allow with a modified command (for transparent interception). This tells Claude Code “allow this tool, but replace the command with this one”. Used when RCH has already executed remotely and wants to substitute a no-op.
Fields
hook_specific_output: AllowWithModifiedHookSpecificOutputTrait Implementations
Sourceimpl Clone for AllowWithModifiedCommandOutput
impl Clone for AllowWithModifiedCommandOutput
Sourcefn clone(&self) -> AllowWithModifiedCommandOutput
fn clone(&self) -> AllowWithModifiedCommandOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for AllowWithModifiedCommandOutput
impl RefUnwindSafe for AllowWithModifiedCommandOutput
impl Send for AllowWithModifiedCommandOutput
impl Sync for AllowWithModifiedCommandOutput
impl Unpin for AllowWithModifiedCommandOutput
impl UnsafeUnpin for AllowWithModifiedCommandOutput
impl UnwindSafe for AllowWithModifiedCommandOutput