shell_escape_value

Function shell_escape_value 

pub fn shell_escape_value(value: &str) -> Option<String>
Escape a string for use in a shell command.

Wraps the string in single quotes and escapes internal single quotes. Returns None if the string contains unsafe control characters (newline, carriage return, NUL).