pub struct RetryConfig {
pub max_attempts: u32,
pub base_delay_ms: u64,
pub max_delay_ms: u64,
pub jitter_factor: f64,
pub total_timeout_ms: u64,
}Expand description
Configuration for retry behavior on transient errors.
Used by rsync and SSH operations to recover from transient network failures without blocking too long or retrying non-recoverable errors.
Fields
max_attempts: u32Maximum number of retry attempts (1 = no retries, just initial attempt).
base_delay_ms: u64Initial delay between retries in milliseconds.
max_delay_ms: u64Maximum delay between retries in milliseconds (caps exponential backoff).
jitter_factor: f64Jitter factor (0.0 - 1.0) to randomize delay. A value of 0.1 means ±10% randomization.
total_timeout_ms: u64Total timeout for all retry attempts in milliseconds. After this, retries stop even if max_attempts not reached.
Implementations
Sourceimpl RetryConfig
impl RetryConfig
Sourcepub fn delay_for_attempt(&self, attempt: u32) -> Duration
pub fn delay_for_attempt(&self, attempt: u32) -> Duration
Calculate delay for a given attempt number (0-indexed).
Uses exponential backoff with optional jitter.
Sourcepub fn should_retry(&self, attempt: u32, elapsed: Duration) -> bool
pub fn should_retry(&self, attempt: u32, elapsed: Duration) -> bool
Check if we should retry given elapsed time since start.