pub fn display_error_with_code<E: Error>(
error: &E,
code: ErrorCode,
ctx: &OutputContext,
)Expand description
Display an error with a specific error code.
Uses the error catalog to provide consistent error codes and remediation.
pub fn display_error_with_code<E: Error>(
error: &E,
code: ErrorCode,
ctx: &OutputContext,
)Display an error with a specific error code.
Uses the error catalog to provide consistent error codes and remediation.