pub fn binary_contains_marker(path: &Path, marker: &str) -> Result<bool>Expand description
Check if a binary contains a specific marker string.
This is used to verify that the remote worker actually compiled the code by checking for a unique test marker that was added to the source.
Arguments
path- Path to the binary filemarker- The marker string to search for
Returns
true if the marker is found in the binary’s string data