Platform-independent SSH utilities.
These utilities work on all platforms and don’t depend on openssh.
Structs
- Command
Result - Result of a remote command execution.
- EnvPrefix
- Environment variable prefix for remote command execution.
Functions
- build_
env_ prefix - Build a shell-safe environment variable prefix from an allowlist.
- is_
retryable_ transport_ error - True if an SSH/transport error looks retryable (transient network / transport).
- is_
retryable_ transport_ error_ text - Message-only variant of
is_retryable_transport_error(useful for tests). - is_
valid_ env_ key - Check if a string is a valid environment variable key.
- shell_
escape_ path_ with_ home - Escape a path for use in a shell command, allowing
~to expand to$HOME. - shell_
escape_ value - Escape a string for use in a shell command.