pub struct SavedTimeStats {
pub total_remote_duration_ms: u64,
pub estimated_local_duration_ms: u64,
pub time_saved_ms: u64,
pub builds_counted: usize,
pub avg_speedup: f64,
pub today_saved_ms: u64,
pub week_saved_ms: u64,
}Expand description
Saved time statistics from remote builds.
Tracks estimated time savings from offloading builds to remote workers. Uses local build history to estimate what remote builds would have taken locally.
Fields
total_remote_duration_ms: u64Total time spent on remote builds (milliseconds).
estimated_local_duration_ms: u64Estimated total time if those builds ran locally (milliseconds).
time_saved_ms: u64Time saved by offloading (milliseconds). Computed as max(0, estimated_local - remote).
builds_counted: usizeNumber of remote builds included in calculation.
avg_speedup: f64Average speedup factor (local_estimate / remote_duration). A value of 2.0 means remote builds are ~2x faster than local.
today_saved_ms: u64Total time saved today (milliseconds).
week_saved_ms: u64Total time saved this week (milliseconds).